// Copyright 2018 Drone.IO Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package model

type SenderService interface {
	SenderAllowed(*User, *Repo, *Build, *Config) (bool, error)
	SenderCreate(*Repo, *Sender) error
	SenderUpdate(*Repo, *Sender) error
	SenderDelete(*Repo, string) error
	SenderList(*Repo) ([]*Sender, error)
}

type SenderStore interface {
	SenderFind(*Repo, string) (*Sender, error)
	SenderList(*Repo) ([]*Sender, error)
	SenderCreate(*Sender) error
	SenderUpdate(*Sender) error
	SenderDelete(*Sender) error
}

type Sender struct {
	ID     int64    `json:"-"      meddler:"sender_id,pk"`
	RepoID int64    `json:"-"      meddler:"sender_repo_id"`
	Login  string   `json:"login"  meddler:"sender_login"`
	Allow  bool     `json:"allow"  meddler:"sender_allow"`
	Block  bool     `json:"block"  meddler:"sender_block"`
	Branch []string `json:"branch" meddler:"-"`
	Deploy []string `json:"deploy" meddler:"-"`
	Event  []string `json:"event"  meddler:"-"`
}
